OC.L10N.register(
    "mail",
    {
    "Important" : "Viktig",
    "Work" : "Arbeid",
    "Personal" : "Personleg",
    "Mail" : "Post",
    "Name" : "Namn",
    "Password" : "Passord",
    "None" : "Ingen",
    "Save" : "Lagre",
    "Connect" : "Kopla til",
    "Signature" : "Signatur",
    "Cancel" : "Avbryt",
    "Delete" : "Ta bort",
    "Search" : "Search",
    "Send" : "Send",
    "Refresh" : "Last inn på nytt",
    "Choose" : "Vel",
    "Favorite" : "Favoritt",
    "Select" : "Vel",
    "Back" : "Tilbake",
    "Description" : "Skildring",
    "Create" : "Lag",
    "Comment" : "Kommentér",
    "Other" : "Anna",
    "Reply" : "Svare",
    "Move" : "Move",
    "Quota" : "Kvote",
    "Saving" : "Lagrar",
    "Retry" : "Forsøk att",
    "Add" : "Legg til",
    "Close" : "Lat att",
    "Date" : "Dato",
    "Tags" : "Emneord",
    "Disabled" : "Deaktivert",
    "Remove" : "Fjern",
    "Client ID" : "Klient-ID",
    "General" : "Generelt",
    "User" : "Bruker",
    "Host" : "Tenar",
    "Port" : "Port",
    "Certificate" : "Sertifikat",
    "All" : "Alle",
    "Favorites" : "Favorit",
    "Sent" : "Sendt",
    "Message sent" : "Melding sendt"
},
"nplurals=2; plural=(n != 1);");
